pub struct TablesInput<'t> { /* private fields */ }Expand description
An object containing table-related vtables
It’s used as a token to prove you’re allowed to read/write tables or manage their fields
Implementations
Sourceimpl TablesInput<'_>
impl TablesInput<'_>
Sourceimpl TablesInput<'_>
impl TablesInput<'_>
Sourcepub fn get_table<T, K>(&self, name: &CStr) -> Result<T, Error>where
T: TableAccess<Key = K>,
K: Key,
pub fn get_table<T, K>(&self, name: &CStr) -> Result<T, Error>where
T: TableAccess<Key = K>,
K: Key,
Import a table from the Falco plugin API
The key type is verified by the plugin API, so this method will return an error on mismatch
Sourcepub fn list_tables(&self) -> &[TableInfo]
pub fn list_tables(&self) -> &[TableInfo]
List the available tables